@@ -115,44 +115,50 @@ from ._events import *
 from ._util import LocalProtocolError, make_sentinel
 
 # Everything in __all__ gets re-exported as part of the h11 public API.
-__all__ = []
+__all__ = [
+    "CLIENT",
+    "SERVER",
+    "IDLE",
+    "SEND_RESPONSE",
+    "SEND_BODY",
+    "DONE",
+    "MUST_CLOSE",
+    "CLOSED",
+    "MIGHT_SWITCH_PROTOCOL",
+    "SWITCHED_PROTOCOL",
+    "ERROR",
+]
 
-# Be careful of trailing whitespace here:
-sentinels = ("CLIENT SERVER "
-             # States
-             "IDLE SEND_RESPONSE SEND_BODY DONE MUST_CLOSE CLOSED "
-             "MIGHT_SWITCH_PROTOCOL SWITCHED_PROTOCOL ERROR "
-             # Switch types
-             "_SWITCH_UPGRADE _SWITCH_CONNECT").split()
-for token in sentinels:
-    globals()[token] = make_sentinel(token)
+CLIENT = make_sentinel("CLIENT")
+SERVER = make_sentinel("SERVER")
 
-__all__ += [s for s in sentinels if not s.startswith("_")]
+# States
+IDLE = make_sentinel("IDLE")
+SEND_RESPONSE = make_sentinel("SEND_RESPONSE")
+SEND_BODY = make_sentinel("SEND_BODY")
+DONE = make_sentinel("DONE")
+MUST_CLOSE = make_sentinel("MUST_CLOSE")
+CLOSED = make_sentinel("CLOSED")
+ERROR = make_sentinel("ERROR")
+
+# Switch types
+MIGHT_SWITCH_PROTOCOL = make_sentinel("MIGHT_SWITCH_PROTOCOL")
+SWITCHED_PROTOCOL = make_sentinel("SWITCHED_PROTOCOL")
+
+_SWITCH_UPGRADE = make_sentinel("_SWITCH_UPGRADE")
+_SWITCH_CONNECT = make_sentinel("_SWITCH_CONNECT")
 
 EVENT_TRIGGERED_TRANSITIONS = {
     CLIENT: {
-        IDLE: {
-            Request: SEND_BODY,
-            ConnectionClosed: CLOSED,
-        },
-        SEND_BODY: {
-            Data: SEND_BODY,
-            EndOfMessage: DONE,
-        },
-        DONE: {
-            ConnectionClosed: CLOSED,
-        },
-        MUST_CLOSE: {
-            ConnectionClosed: CLOSED,
-        },
-        CLOSED: {
-            ConnectionClosed: CLOSED,
-        },
+        IDLE: {Request: SEND_BODY, ConnectionClosed: CLOSED},
+        SEND_BODY: {Data: SEND_BODY, EndOfMessage: DONE},
+        DONE: {ConnectionClosed: CLOSED},
+        MUST_CLOSE: {ConnectionClosed: CLOSED},
+        CLOSED: {ConnectionClosed: CLOSED},
         MIGHT_SWITCH_PROTOCOL: {},
         SWITCHED_PROTOCOL: {},
         ERROR: {},
     },
-
     SERVER: {
         IDLE: {
             ConnectionClosed: CLOSED,
@@ -166,19 +172,10 @@ EVENT_TRIGGERED_TRANSITIONS = {
             (InformationalResponse, _SWITCH_UPGRADE): SWITCHED_PROTOCOL,
             (Response, _SWITCH_CONNECT): SWITCHED_PROTOCOL,
         },
-        SEND_BODY: {
-            Data: SEND_BODY,
-            EndOfMessage: DONE,
-        },
-        DONE: {
-            ConnectionClosed: CLOSED,
-        },
-        MUST_CLOSE: {
-            ConnectionClosed: CLOSED,
-        },
-        CLOSED: {
-            ConnectionClosed: CLOSED,
-        },
+        SEND_BODY: {Data: SEND_BODY, EndOfMessage: DONE},
+        DONE: {ConnectionClosed: CLOSED},
+        MUST_CLOSE: {ConnectionClosed: CLOSED},
+        CLOSED: {ConnectionClosed: CLOSED},
         SWITCHED_PROTOCOL: {},
         ERROR: {},
     },
@@ -199,6 +196,7 @@ STATE_TRIGGERED_TRANSITIONS = {
     (DONE, ERROR): {CLIENT: MUST_CLOSE},
 }
 
+
 class ConnectionState(object):
     def __init__(self):
         # Extra bits of state that don't quite fit into the state model.
@@ -230,8 +228,10 @@ class ConnectionState(object):
             assert role is SERVER
             if server_switch_event not in self.pending_switch_proposals:
                 raise LocalProtocolError(
-                    "Received server {} event without a pending proposal"
-                    .format(server_switch_event))
+                    "Received server {} event without a pending proposal".format(
+                        server_switch_event
+                    )
+                )
             event_type = (event_type, server_switch_event)
         if server_switch_event is None and event_type is Response:
             self.pending_switch_proposals = set()
@@ -249,8 +249,10 @@ class ConnectionState(object):
             new_state = EVENT_TRIGGERED_TRANSITIONS[role][state][event_type]
         except KeyError:
             raise LocalProtocolError(
-                "can't handle event type {} when role={} and state={}"
-                .format(event_type.__name__, role, self.states[role]))
+                "can't handle event type {} when role={} and state={}".format(
+                    event_type.__name__, role, self.states[role]
+                )
+            )
         self.states[role] = new_state
 
     def _fire_state_triggered_transitions(self):
@@ -295,7 +297,9 @@ class ConnectionState(object):
 
     def start_next_cycle(self):
         if self.states != {CLIENT: DONE, SERVER: DONE}:
-            raise LocalProtocolError("not in a reusable state")
+            raise LocalProtocolError(
+                "not in a reusable state. self.states={}".format(self.states)
+            )
         # Can't reach DONE/DONE with any of these active, but still, let's be
         # sure.
         assert self.keep_alive
